@@ -24,7 +24,7 @@ class MV(Gtk.Box):
             return
         self.first_show = True
         app = self.app
-        self.buttonbox = Gtk.Box()
+        self.buttonbox = Gtk.Box(spacing=5)
         self.pack_start(self.buttonbox, False, False, 0)
         button_home = Gtk.Button(_('MV'))
         button_home.connect('clicked', self.on_button_home_clicked)
